@@ -19,35 +19,36 @@ Examples:
   print math.sin(x**2)  # Prints "0.0399...+-0.00399..."
 
   # Access to the value at the origin, and to the uncertainty:
-  y = x**2
-  print y  # Prints "0.04+-0.004"  
-  print y.origin_value  # Prints "0.04"
-  print y.std_dev()  # Prints "0.004..."
+  s = x**2  # Square
+  print s  # Prints "0.04+-0.004"  
+  print s.origin_value  # Prints "0.04"
+  print s.std_dev()  # Prints "0.004..."
 
-  print y.derivatives[x]  # Partial derivative: prints "2"
+  print s.derivatives[x]  # Partial derivative: prints "0.4" (= 2*0.20)
   
-  # List of all sources of error:
-  u = uncertainties.Number_with_uncert((0.2, 0.05), "u variable")  # Tag
+  # Correlations:
+  u = uncertainties.Number_with_uncert((1, 0.05), "u variable")  # Tag
   v = uncertainties.Number_with_uncert((10,  0.1),  "v variable")
   sum_value = u+v
-  print sum_value  # Prints "10.2+-0.11..."
-  for (var, error) in sum_value.error_components().iteritems():
-      print "%s: %f" % (var.tag, error)  # Individual error components
-
-  # Correlations:
+  
   u.set_std_dev(0.1)  # Standard deviations can be updated on the fly
   print sum_value - u - v  # Prints "0.0" (exact result)
 
-  # Correlation matrices:
-  correlation_matrix = uncertainties.correlations([u, v, u+v])
-  print correlation_matrix  # 3x3 matrix
+  # List of all sources of error:
+  print sum_value  # Prints "11+-0.1414..."
+  for (var, error) in sum_value.error_components().iteritems():
+      print "%s: %f" % (var.tag, error)  # Individual error components
 
-  # Correlated variables can be constructed from a correlation matrix, if
+  # Covariance matrices:
+  cov_matrix = uncertainties.covariance_matrix([u, v, u+v])
+  print cov_matrix  # 3x3 matrix
+
+  # Correlated variables can be constructed from a covariance matrix, if
   # Numpy is available:
-  (u2, v2, sum2) = uncertainties.correlated_values([0.2, 10, 10.2],
-                                                   correlation_matrix)
-  print u2  # Value and uncertainty of u: correctly recovered (0.2+-0.05)
-  print uncertainties.correlations([u2, u2, sum2])  # = correlation_matrix
+  (u2, v2, sum2) = uncertainties.correlated_values([1, 10, 11],
+                                                   cov_matrix)
+  print u2  # Value and uncertainty of u: correctly recovered (1+-0.1)
+  print uncertainties.covariance_matrix([u2, u2, sum2])  # = cov_matrix
 
 - The main class provided by this module is Number_with_uncert, which
 represents numbers with uncertainties.  Number_with_uncert objects can
@@ -64,10 +65,10 @@ Logical operations (>, ==, etc.) are also supported.
 Many operations on Numpy arrays are supported, including inverting a
 matrix that contains numbers with uncertainties.
 
-- A few utility functions are provided: correlations between functions
-can be calculated [correlations()], or used as input for the
-definition of correlated quantities [correlated_values(), defined only
-if the numpy module is available].
+- Utility functions are provided: the covariance matrix between
+functions can be calculated [covariance_matrix()], or used as input
+for the definition of correlated quantities [correlated_values(),
+defined only if the numpy module is available].
 
 - Logical operations on Number_with_uncert objects have a pragmatic
 semantics: Number_with_uncert objects can be used where Python numbers
@@ -104,11 +105,14 @@ deviation of mathematical results.
 - This module contains tests.  They can be run either manually or
 automatically with the nose unit testing framework (nosetests).
 
+- The author wishes to thank Arnaud Delobelle, Pierre Clade, and
+contributors to the comp.lang.python newsgroup for valuable input.
+
 (c) 2009 by Eric O. LEBIGOT (EOL) <eric.lebigot@normalesup.org>
 Please send feature requests, bug reports, or feedback to this address.
 
-This software is released under a dual license.  (1) The GNU General \
-Public License version 2.  (2) Any other license, as long as it is \
+This software is released under a dual license.  (1) The GNU General
+Public License version 2.  (2) Any other license, as long as it is
 obtained from the original author.'''
 
 # The idea behind this module is to replace the result of mathematical
@@ -129,7 +133,12 @@ from types import BuiltinFunctionType
 
 import random  # For unit testing (test_...() functions)
 
-__all__ = ["Number_with_uncert", "correlations"]
+# Attributes that are always exported (some other attributes are
+# exported only if the numpy module is available...):
+__all__ = [
+    'Number_with_uncert',  # Main class: number with uncertainty
+    'covariance_matrix'
+    ]
 
 ###############################################################################
 
@@ -939,18 +948,18 @@ def _get_origin_value(n):
 
     return n.origin_value if isinstance(n, AffineScalarFunc) else n
 
-def correlations(expressions):
+def covariance_matrix(expressions):
     """
-    Returns a matrix that contains the correlations between the given
+    Returns a matrix that contains the covariances between the given
     AffineScalarFunc objects (iterable).  They must be ordered in some
     way (list, tuple,...), as the resulting matrix implicitly depends
     on their ordering.
 
-    The correlation coefficients are floats (never int objects).
+    The covariances are floats (never int objects).
     """
     # See PSI.411.
 
-    correlation_matrix = []
+    covariance_matrix = []
     for (i1, expr1) in enumerate(expressions):
         derivatives1 = expr1.derivatives  # Optimization
         vars1 = set(derivatives1)
@@ -962,14 +971,14 @@ def correlations(expressions):
                 # var is a variable common to both expressions:
                 coef += (derivatives1[var]*derivatives2[var]*var._std_dev**2)
             coefs_expr1.append(coef)
-        correlation_matrix.append(coefs_expr1)
+        covariance_matrix.append(coefs_expr1)
 
     # We symmetrize the matrix:
-    for (i, correlation_coefs) in enumerate(correlation_matrix):
-        correlation_coefs.extend(correlation_matrix[j][i]
-                                 for j in range(i+1, len(correlation_matrix)))
+    for (i, covariance_coefs) in enumerate(covariance_matrix):
+        covariance_coefs.extend(covariance_matrix[j][i]
+                                 for j in range(i+1, len(covariance_matrix)))
 
-    return correlation_matrix
+    return covariance_matrix
 
 # Entering variables as a block of correlated values.  Only available
 # if Numpy is installed.
@@ -995,13 +1004,13 @@ else:
         # Parenthesis are here for negative coefficients:
         return '+'.join("(%r*%s)" % (c, t) for (c, t) in zip(coefs, tags))
     
-    def correlated_values(values, correlations, tags = None):
+    def correlated_values(values, covariance_mat, tags = None):
         """
-        Return AffineScalarFunc objects that correctly reproduce the
-        given correlation matrix.
+        Returns AffineScalarFunc objects that correctly reproduce the
+        given covariance matrix.
 
-        The list of values and the correlation matrix must have the
-        same length (and the matrix is a square one).
+        The list of values and the covariance matrix must have the
+        same length, and the matrix must be a square one.
 
         The affine functions returned depend on newly created,
         independent variables (Variable objects).
@@ -1013,10 +1022,10 @@ else:
         the returned AffineScalarFunc objects).
         """
 
-        # The correlation matrix is diagonalized in order to define
+        # The covariance matrix is diagonalized in order to define
         # the independent variables that model the given values:
 
-        (variances, transform) = linalg.eigh(correlations)
+        (variances, transform) = linalg.eigh(covariance_mat)
 
         # Numerical errors might make some variances negative: we set
         # them to zero:
@@ -1827,7 +1836,7 @@ def test_numpy():
                               m_inv_uncert[1, 1].origin_value)
 
 
-        # Checks of the correlations between elements:
+        # Checks of the covariances between elements:
         x = Number_with_uncert((10, 1))
         m = numpy.mat([[x, x],
                        [0, 3+2*x]])
@@ -1838,7 +1847,7 @@ def test_numpy():
         # Check of the properties of the inverse:
         m_double_inverse = m_inverse.I
         # The initial matrix should be recovered, including its
-        # derivatives, which define correlations:
+        # derivatives, which define covariances:
         assert _numbers_close(m_double_inverse[0, 0].origin_value,
                               m[0, 0].origin_value)
         assert _numbers_close(m_double_inverse[0, 0].std_dev(),
@@ -1892,9 +1901,10 @@ def test_numpy():
 
         ####################
 
-        # Tests of correlations during the inversion:
+        # Tests of covariances during the inversion:
         
-        # There are correlations if both next two derivatives are not zero:
+        # There are correlations if both the next two derivatives are
+        # not zero:
         assert m_inverse[0, 0].derivatives[x]
         assert m_inverse[0, 1].derivatives[x]
 
@@ -1904,12 +1914,12 @@ def test_numpy():
 
         ########################################
 
-        # Correlations between output and input variables:
+        # Covariances between output and input variables:
         
         x = Number_with_uncert((1, 0.1))
         y = -2*x+10
         z = -3*x
-        corrs = correlations([x, y, z])
+        corrs = covariance_matrix([x, y, z])
         # Diagonal elements are simple:
         assert _numbers_close(corrs[0][0], 0.01)
         assert _numbers_close(corrs[1][1], 0.04)
@@ -1917,7 +1927,8 @@ def test_numpy():
         # Non-diagonal elements:
         assert _numbers_close(corrs[0][1], -0.02)
 
-        # "Inversion" of correlations: creation of new variables:
+        # "Inversion" of the covariance matrix: creation of new
+        # variables:
         (x_new, y_new, z_new) = correlated_values(
             [x.origin_value, y.origin_value, z.origin_value],
             corrs,
@@ -1927,10 +1938,10 @@ def test_numpy():
         assert _matrices_almost_equal(numpy.array((x, y, z)),
                                       numpy.array((x_new, y_new, z_new)))
 
-        # ... and correlations too:
+        # ... and the covariances too:
         assert _matrices_almost_equal(
             numpy.array(corrs),
-            numpy.array(correlations([x_new, y_new, z_new])))
+            numpy.array(covariance_matrix([x_new, y_new, z_new])))
 
         assert _matrices_almost_equal(
             numpy.array([y_new]), numpy.array([-2*x_new+10]))
